@@ -83,7 +83,7 @@ SettingsDialog::SettingsDialog(QWidget *parent, int activeTab) : QDialog(parent)
         ui->fullscreenOption->setChecked(true);
 
     QStringList useableModes, modes;
-    useableModes << "default"; //Allow users to use the screen resolution set in the config file
+    useableModes << tr("default"); //Allow users to use the screen resolution set in the config file
 
     modes << "2560x1600"
           << "2560x1440"
@@ -361,7 +361,8 @@ SettingsDialog::SettingsDialog(QWidget *parent, int activeTab) : QDialog(parent)
 
     QList<QStringList> languages;
     languages << (QStringList() << QString::fromUtf8("English")  << "EN")
-              << (QStringList() << QString::fromUtf8("Français") << "FR");
+              << (QStringList() << QString::fromUtf8("Français") << "FR")
+              << (QStringList() << QString::fromUtf8("Русский") << "RU");
 
     downloadEnable << ui->tableSizeLabel
                    << ui->tableSizeBox
@@ -390,6 +391,9 @@ SettingsDialog::SettingsDialog(QWidget *parent, int activeTab) : QDialog(parent)
 
     ui->languageInfoLabel->setHidden(true);
 
+    ui->buttonBox->button(QDialogButtonBox::Ok)->setText(tr("OK"));
+    ui->buttonBox->button(QDialogButtonBox::Cancel)->setText(tr("Cancel"));
+
     connect(ui->downloadOption, SIGNAL(toggled(bool)), this, SLOT(toggleDownload(bool)));
     connect(ui->downloadOption, SIGNAL(toggled(bool)), this, SLOT(populateTableAndListTab(bool)));
     connect(ui->languageBox, SIGNAL(currentIndexChanged(int)), this, SLOT(updateLanguageInfo()));
