@@ -37,15 +37,9 @@
 #include <QDir>
 #include <QFile>
 #include <QMessageBox>
-#include <QProcess>
 
-#if QT_VERSION >= 0x050000
 #include <quazip5/quazip.h>
 #include <quazip5/quazipfile.h>
-#else
-#include <quazip/quazip.h>
-#include <quazip/quazipfile.h>
-#endif
 
 
 EmulatorHandler::EmulatorHandler(QWidget *parent) : QObject(parent)
@@ -55,16 +49,16 @@ EmulatorHandler::EmulatorHandler(QWidget *parent) : QObject(parent)
     lastOutput = "";
 }
 
-void EmulatorHandler::checkStatus(int status)
+void EmulatorHandler::checkStatus(int status, QProcess::ExitStatus exitStatus)
 {
-    if (status > 0) {
+    if (status != 0 || exitStatus != QProcess::NormalExit) {
         QMessageBox exitDialog(parent);
         exitDialog.setWindowTitle(tr("Warning"));
         exitDialog.setText(tr("<ParentName> quit unexpectedly. Check the log for more information.")
                            .replace("<ParentName>",ParentName));
         exitDialog.setIcon(QMessageBox::Warning);
         exitDialog.addButton(QMessageBox::Ok);
-        exitDialog.addButton(tr("View Log..."), QMessageBox::HelpRole);
+        exitDialog.addButton(tr("View Log"), QMessageBox::HelpRole);
 
         int ret = exitDialog.exec();
         if (ret == 0) emit showLog();
@@ -125,7 +119,12 @@ QStringList EmulatorHandler::parseArgString(QString argString)
 
 void EmulatorHandler::readOutput()
 {
-    lastOutput.append(emulatorProc->readAllStandardOutput());
+    QString output = emulatorProc->readAllStandardOutput();
+    if (output != "")
+        lastOutput.append(output);
+    else
+        lastOutput.append("\n" + tr("There was no output. If you were expecting Mupen64Plus to run, try copying")
+                          + "\n" + tr("the above command into a command prompt to see if you get an error."));
 }
 
 
@@ -272,7 +271,8 @@ void EmulatorHandler::startEmulator(QDir romDir, QString romFileName, QString zi
     emulatorProc = new QProcess(this);
     connect(emulatorProc, SIGNAL(finished(int)), this, SLOT(readOutput()));
     connect(emulatorProc, SIGNAL(finished(int)), this, SLOT(emitFinished()));
-    connect(emulatorProc, SIGNAL(finished(int)), this, SLOT(checkStatus(int)));
+    connect(emulatorProc, SIGNAL(finished(int, QProcess::ExitStatus)), this,
+            SLOT(checkStatus(int, QProcess::ExitStatus)));
 
     if (zip)
         connect(emulatorProc, SIGNAL(finished(int)), this, SLOT(cleanTemp()));
