@@ -36,6 +36,7 @@
 
 #include "dialogs/aboutdialog.h"
 #include "dialogs/configeditor.h"
+#include "dialogs/controlinfodialog.h"
 #include "dialogs/downloaddialog.h"
 #include "dialogs/gamesettingsdialog.h"
 #include "dialogs/logdialog.h"
@@ -59,6 +60,7 @@
 #include <QListWidget>
 #include <QMenuBar>
 #include <QMessageBox>
+#include <QOperatingSystemVersion>
 #include <QTimer>
 #include <QVBoxLayout>
 
@@ -202,15 +204,17 @@ void MainWindow::autoloadSettings()
 #endif
     }
 
+    checkConfigLocation();
+}
+
+
+void MainWindow::checkConfigLocation()
+{
     //Check default location for mupen64plus.cfg in case user wants to use editor
     QString configPath = SETTINGS.value("Paths/config", "").toString();
 
     if (configPath == "") {
-#if QT_VERSION >= 0x050000
         QString homeDir = QStandardPaths::standardLocations(QStandardPaths::HomeLocation).first();
-#else
-        QString homeDir = QDesktopServices::storageLocation(QDesktopServices::HomeLocation);
-#endif
 
 #ifdef Q_OS_WIN
         QString configCheck = homeDir + "/AppData/Roaming/Mupen64Plus/";
@@ -279,7 +283,7 @@ void MainWindow::createMenu()
     startAction = emulationMenu->addAction(tr("&Start"));
     stopAction = emulationMenu->addAction(tr("St&op"));
     emulationMenu->addSeparator();
-    logAction = emulationMenu->addAction(tr("View Log..."));
+    logAction = emulationMenu->addAction(tr("View Log"));
 
     startAction->setIcon(QIcon::fromTheme("media-playback-start"));
     stopAction->setIcon(QIcon::fromTheme("media-playback-stop"));
@@ -343,15 +347,17 @@ void MainWindow::createMenu()
 
     viewMenu->addSeparator();
 
-#if QT_VERSION >= 0x050000
     //OSX El Capitan adds it's own full-screen option
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    if (!(QOperatingSystemVersion::current() >= QOperatingSystemVersion::OSXElCapitan &&
+            QOperatingSystemVersion::currentType() == QOperatingSystemVersion::MacOS))
+#else
     if (QSysInfo::macVersion() < QSysInfo::MV_ELCAPITAN || QSysInfo::macVersion() == QSysInfo::MV_None)
+#endif
         fullScreenAction = viewMenu->addAction(tr("&Full-screen"));
     else
         fullScreenAction = new QAction(this);
-#else
-    fullScreenAction = viewMenu->addAction(tr("&Full-screen"));
-#endif
+
     fullScreenAction->setCheckable(true);
 
     if (SETTINGS.value("View/fullscreen", "") == "true")
@@ -365,10 +371,18 @@ void MainWindow::createMenu()
 
     //Help
     helpMenu = new QMenu(tr("&Help"), this);
+    documentationAction = helpMenu->addAction(tr("Documentation"));
+    mupenDocsAction = helpMenu->addAction(tr("Mupen64Plus Docs"));
+    helpMenu->addSeparator();
+    controlInfoAction = helpMenu->addAction(tr("Default Controls"));
+    helpMenu->addSeparator();
     aboutAction = helpMenu->addAction(tr("&About"));
     aboutAction->setIcon(QIcon::fromTheme("help-about"));
     menuBar->addMenu(helpMenu);
 
+    connect(documentationAction, SIGNAL(triggered()), this, SLOT(openDocumentation()));
+    connect(mupenDocsAction, SIGNAL(triggered()), this, SLOT(openMupenDocs()));
+    connect(controlInfoAction, SIGNAL(triggered()), this, SLOT(openDefaultControls()));
     connect(aboutAction, SIGNAL(triggered()), this, SLOT(openAbout()));
 
 
@@ -439,14 +453,13 @@ void MainWindow::createRomView()
     //Create disabled view
     disabledView = new QWidget(this);
     disabledView->setHidden(true);
-    disabledView->setDisabled(true);
 
     disabledLayout = new QVBoxLayout(disabledView);
     disabledLayout->setSizeConstraint(QLayout::SetMinAndMaxSize);
     disabledView->setLayout(disabledLayout);
 
-    QString disabledText = QString("Add a directory containing ROMs under ")
-                         + "Settings->Configure->Paths to use this view.";
+    QString disabledText = QString(tr("Add a directory containing ROMs under "))
+                         + tr("Settings->Configure->Paths to use this view.");
     disabledLabel = new QLabel(disabledText, disabledView);
     disabledLabel->setWordWrap(true);
     disabledLabel->setAlignment(Qt::AlignCenter);
@@ -549,12 +562,7 @@ bool MainWindow::eventFilter(QObject*, QEvent *event)
     if (event->type() == QEvent::HoverMove && isFullScreen()) {
         QMouseEvent *mouseEvent = static_cast<QMouseEvent*>(event);
 
-        //x and y axis are reversed in Qt4
-#if QT_VERSION >= 0x050000
         int mousePos = mouseEvent->pos().y();
-#else
-        int mousePos = mouseEvent->pos().x();
-#endif
 
         if (mousePos < 5)
             showMenuBar(true);
@@ -570,9 +578,13 @@ bool MainWindow::eventFilter(QObject*, QEvent *event)
             updateFullScreenMode();
     }
 
-#if QT_VERSION >= 0x050000
     //OSX El Capitan adds it's own full-screen option, so handle the event change here
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+    if (QOperatingSystemVersion::current() >= QOperatingSystemVersion::OSXElCapitan &&
+            QOperatingSystemVersion::currentType() == QOperatingSystemVersion::MacOS) {
+#else
     if (QSysInfo::macVersion() >= QSysInfo::MV_ELCAPITAN && QSysInfo::macVersion() != QSysInfo::MV_None) {
+#endif
         if (event->type() == QEvent::WindowStateChange) {
             QWindowStateChangeEvent *windowEvent = static_cast<QWindowStateChangeEvent*>(event);
 
@@ -589,7 +601,6 @@ bool MainWindow::eventFilter(QObject*, QEvent *event)
             }
         }
     }
-#endif
 
     return false;
 }
@@ -656,6 +667,12 @@ void MainWindow::openAbout()
     aboutDialog.exec();
 }
 
+void MainWindow::openDefaultControls()
+{
+    ControlInfo controlInfo(this);
+    controlInfo.exec();
+}
+
 
 void MainWindow::openDeleteDialog()
 {
@@ -667,6 +684,12 @@ void MainWindow::openDeleteDialog()
 }
 
 
+void MainWindow::openDocumentation()
+{
+    QDesktopServices::openUrl(QUrl("https://github.com/dh4/mupen64plus-qt#table-of-contents"));
+}
+
+
 void MainWindow::openDownloader()
 {
     DownloadDialog downloadDialog(getCurrentRomInfoFromView("fileName"),
@@ -681,6 +704,8 @@ void MainWindow::openDownloader()
 
 void MainWindow::openEditor()
 {
+    checkConfigLocation();
+
     QString configPath = SETTINGS.value("Paths/config", "").toString();
     QDir configDir = QDir(configPath);
     QString configFile = configDir.absoluteFilePath("mupen64plus.cfg");
@@ -690,8 +715,8 @@ void MainWindow::openEditor()
         QMessageBox::information(this, tr("Not Found"), QString(tr("Editor requires config directory to be "))
                                  + tr("set to a directory with mupen64plus.cfg.") + "<br /><br />"
                                  + tr("See here for the default config location:") + "<br />"
-                                 + "<a href=\"http://mupen64plus.org/wiki/index.php?title=FileLocations\">"
-                                 + "http://mupen64plus.org/wiki/index.php?title=FileLocations</a>");
+                                 + "<a href=\"https://mupen64plus.org/wiki/index.php?title=FileLocations\">"
+                                 + "https://mupen64plus.org/wiki/index.php?title=FileLocations</a>");
     } else {
         ConfigEditor configEditor(configFile, this);
         configEditor.exec();
@@ -719,6 +744,12 @@ void MainWindow::openLog()
 }
 
 
+void MainWindow::openMupenDocs()
+{
+    QDesktopServices::openUrl(QUrl("https://mupen64plus.org/docs/"));
+}
+
+
 void MainWindow::openSettings()
 {
     QString tableImageBefore = SETTINGS.value("Table/imagesize", "Medium").toString();
@@ -764,11 +795,7 @@ void MainWindow::openRom()
     foreach (QString type, romCollection->getFileTypes(true)) filter += type + " ";
     filter += ");;" + tr("All Files") + " (*)";
 
-#if QT_VERSION >= 0x050000
     QString searchPath = QStandardPaths::standardLocations(QStandardPaths::HomeLocation).first();
-#else
-    QString searchPath = QDesktopServices::storageLocation(QDesktopServices::HomeLocation);
-#endif
     if (romCollection->romPaths.count() > 0)
         searchPath = romCollection->romPaths.at(0);
 
@@ -823,7 +850,7 @@ void MainWindow::openZipDialog(QStringList zippedFiles)
 
     zipButtonBox = new QDialogButtonBox(Qt::Horizontal, zipDialog);
     zipButtonBox->addButton(tr("Launch"), QDialogButtonBox::AcceptRole);
-    zipButtonBox->addButton(QDialogButtonBox::Cancel);
+    zipButtonBox->addButton(tr("Cancel"), QDialogButtonBox::RejectRole);
 
     zipLayout->addWidget(zipList, 0, 0);
     zipLayout->addWidget(zipButtonBox, 1, 0);
